Index: net/base/cookie_monster.h |
diff --git a/net/base/cookie_monster.h b/net/base/cookie_monster.h |
index cdb508ee971e0232cd8dd082d088300a809317dc..3ecea5cf224d8e406f67dda0ba35bae51f26bd66 100644 |
--- a/net/base/cookie_monster.h |
+++ b/net/base/cookie_monster.h |
@@ -168,10 +168,15 @@ class CookieMonster : public CookieStore { |
CookieList GetAllCookies(); |
// Returns all the cookies, for use in management UI, etc. Filters results |
// using given url scheme, host / domain and path. This does not mark the |
// cookies as having been accessed. |
// The returned cookies are ordered by longest path, then earliest |
// creation date. |
+ CookieList GetAllCookiesForURLWithOptions(const GURL& url, |
+ const CookieOptions& options); |
+ |
+ // Invokes GetAllCookiesForURLWithOptions with options set to include HTTP |
+ // only cookies. |
CookieList GetAllCookiesForURL(const GURL& url); |
// Deletes all of the cookies. |
@@ -443,7 +448,7 @@ class CookieMonster : public CookieStore { |
// The resolution of our time isn't enough, so we do something |
// ugly and increment when we've seen the same time twice. |
- base::Time CurrentTime(); |
darin (slow to review)
2010/11/24 18:10:47
we generally try to avoid including X11 headers in
jochen (gone - plz use gerrit)
2010/11/24 18:45:38
the headers get included from chrome/browser/gtk/g
|
+ base::Time StrictlyIncreasingTime(); |
base::Time last_time_seen_; |
// Minimum delay after updating a cookie's LastAccessDate before we will |
@@ -168,10 +168,15 @@ class CookieMonster : public CookieStore { |
CookieList GetAllCookies(); |
// Returns all the cookies, for use in management UI, etc. Filters results |
- // using given url scheme, host / domain and path. This does not mark the |
- // cookies as having been accessed. |
+ // using given url scheme, host / domain and path and options. This does not |
+ // mark the cookies as having been accessed. |
// The returned cookies are ordered by longest path, then earliest |
// creation date. |